@@ -2,23 +2,25 @@
 (*                                                                        *)
 (*  This file is part of Calendar.                                        *)
 (*                                                                        *)
-(*  Copyright (C) 2003-2008 Julien Signoles                               *)
+(*  Copyright (C) 2003-2009 Julien Signoles                               *)
 (*                                                                        *)
 (*  you can redistribute it and/or modify it under the terms of the GNU   *)
 (*  Lesser General Public License version 2.1 as published by the         *)
-(*  Free Software Foundation.                                             *)
+(*  Free Software Foundation, with a special linking exception (usual     *)
+(*  for Objective Caml libraries).                                        *)
 (*                                                                        *)
 (*  It is distributed in the hope that it will be useful,                 *)
 (*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
-(*  GNU Lesser General Public License for more details.                   *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR                           *)
 (*                                                                        *)
 (*  See the GNU Lesser General Public Licence version 2.1 for more        *)
 (*  details (enclosed in the file LGPL).                                  *)
 (*                                                                        *)
+(*  The special linking exception is detailled in the enclosed file       *)
+(*  LICENSE.                                                              *)
 (**************************************************************************)
 
-(*i $Id: time.ml,v 1.22 2008/02/05 15:36:21 signoles Exp $ i*)
+(*i $Id: time.ml 225 2009-12-14 10:36:08Z signoles $ i*)
 
 (*S Introduction.
 
@@ -104,6 +106,7 @@ end
 
 module Period = struct
 
+  type +'a period = int constraint 'a = [< Period.date_field ]
   include Utils.Int
 
   let make h m s = h * 3600 + m * 60 + s
