@@ -1,4 +1,26 @@
-(*i $Id: test_pcalendar.ml,v 1.2 2008/02/08 10:36:14 signoles Exp $ i*)
+(**************************************************************************)
+(*                                                                        *)
+(*  This file is part of Calendar.                                        *)
+(*                                                                        *)
+(*  Copyright (C) 2003-2009 Julien Signoles                               *)
+(*                                                                        *)
+(*  you can redistribute it and/or modify it under the terms of the GNU   *)
+(*  Lesser General Public License version 2.1 as published by the         *)
+(*  Free Software Foundation, with a special linking exception (usual     *)
+(*  for Objective Caml libraries).                                        *)
+(*                                                                        *)
+(*  It is distributed in the hope that it will be useful,                 *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR                           *)
+(*                                                                        *)
+(*  See the GNU Lesser General Public Licence version 2.1 for more        *)
+(*  details (enclosed in the file LGPL).                                  *)
+(*                                                                        *)
+(*  The special linking exception is detailled in the enclosed file       *)
+(*  LICENSE.                                                              *)
+(**************************************************************************)
+
+(*i $Id: test_pcalendar.ml 225 2009-12-14 10:36:08Z signoles $ i*)
 
 Printf.printf "Tests of Precise Calendar:\n";;
 
@@ -125,8 +147,12 @@ test (from_unixtm (to_unixtm (make 2003 7 16 23 22 21)) =
 
 test (Period.to_time (Period.second 30) = Time.Period.second 30) 
   "Period.to_time second";;
+test (Period.safe_to_time (Period.second 30) = Time.Period.second 30) 
+  "Period.safe_to_time second";;
 test (Period.to_time (Period.day 6) = Time.Period.second 518400) 
   "Period.to_time day";;
+test (Period.safe_to_time (Period.day 6) = Time.Period.second 518400) 
+  "Period.safe_to_time day";;
 test_exn (lazy (Period.to_time (Period.year 1))) "Period.to_time year";;
 test (Period.ymds (Period.make 1 2 3 1 2 3) = (1, 2, 3, 3723)) "Period.ymds";;
 test
